# amostra

`amostra` is a collection of light-weight sample management service.

[![Build Status](https://travis-ci.org/NSLS-II/amostra.svg)](https://travis-ci.org/NSLS-II/amostra)
[![Coverage Status](https://coveralls.io/repos/github/NSLS-II/amostra/badge.svg?branch=master)](https://coveralls.io/github/NSLS-II/amostra?branch=master)
[![codecov](https://codecov.io/gh/NSLS-II/amostra/branch/master/graph/badge.svg)](https://codecov.io/gh/NSLS-II/amostra)
[![Code Health](https://landscape.io/github/NSLS-II/amostra/master/landscape.svg?style=flat)](https://landscape.io/github/NSLS-II/amostra/master)

## Conda Recipes

Install the most recent tagged build: `conda install amostra -c lightsource2-tag`

Install the most recent tagged build: `conda install amostra -c lightsource2-dev`

Find the tagged recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-tag/amostra) and the dev recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-dev/amostra)
